@@ -13,7 +13,7 @@ obtain one at http://mozilla.org/MPL/2.0/.
 ----------------------------------------------------------------------------
 https://www.direct-netware.de/redirect?licenses;mpl2
 ----------------------------------------------------------------------------
-v1.0.5
+v1.0.6
 dpt_module_loader/loader.py
 """
 
@@ -21,13 +21,14 @@ dpt_module_loader/loader.py
 
 from contextlib import contextmanager
 from os import path
-from weakref import proxy
 import os
 import sys
 
 from dpt_runtime.exceptions import IOException
 from dpt_threading import ThreadLock
 
+from .abstract_loader import AbstractLoader
+
 _MODE_IMP = 1
 """
 Use "imp" based methods for import
@@ -45,10 +46,10 @@ except ImportError:
     _mode = _MODE_IMP
 #
 
-class Loader(object):
+class Loader(AbstractLoader):
     """
-"Loader" provides singletons and objects based on the package, module
-and class name given as "package.module:Class".
+"Loader" provides singletons and objects based on the package and module
+given as "package.module".
 
 :author:     direct Netware Group et al.
 :copyright:  direct Netware Group - All rights reserved
@@ -71,11 +72,6 @@ Additional base directory we search for python files
     _lock = ThreadLock()
     """
 Thread safety lock
-    """
-    _log_handler = None
-    """
-The log handler is called whenever debug messages should be logged or errors
-happened.
     """
     _namespace_modules_cache = { }
     """
@@ -411,19 +407,6 @@ Sets an additional base directory for scanning and loading python files.
 
         Loader._additional_base_dir = path.abspath(base_dir)
     #
-
-    @staticmethod
-    def set_log_handler(log_handler):
-        """
-Sets the log handler.
-
-:param log_handler: Log handler to use
-
-:since: v1.0.0
-        """
-
-        Loader._log_handler = proxy(log_handler)
-    #
 #
 
 @contextmanager
